Thank you for taking the time to consider making a contribution to the
cfdm package.

Please consult the
[dedicated guidance page](https://ncas-cms.github.io/cfdm/contributing.html)
in the documentation for detailed guidance on contributing to cfdm.

Overall, general questions, suggestions for enhancements, and reports
of bugs are appreciated and should be reported via the
[GitHub issue tracker](https://github.com/NCAS-CMS/cfdm/issues).

Code-change contributions to cfdm are also very welcome, though to
ensure the work is in line with plans for development of the library, please
always discuss any intended changes with the core development team in the
first instance. The standard way to do so is also through the
issue tracker:

* if there is an existing issue in the tracker than you would like
  to address, comment on that issue to indicate you would like to work on
  it;
* conversely, if there is not an issue corresponding to your ideas for
  contribution, please raise a new issue outlining the idea.

If you are not sure about any aspect related to contributing after
reading the guidance page, do not hesitate to get in touch by posting
a question in an issue.
